orion.db.OrionDBExplorer
========================

.. currentmodule:: orion.db

.. autoclass:: OrionDBExplorer

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~OrionDBExplorer.__init__
      ~OrionDBExplorer.add_annotation
      ~OrionDBExplorer.add_datarun
      ~OrionDBExplorer.add_dataset
      ~OrionDBExplorer.add_event
      ~OrionDBExplorer.add_experiment
      ~OrionDBExplorer.add_pipeline
      ~OrionDBExplorer.add_signal
      ~OrionDBExplorer.add_signalrun
      ~OrionDBExplorer.add_signals
      ~OrionDBExplorer.add_template
      ~OrionDBExplorer.drop_database
      ~OrionDBExplorer.get_annotation
      ~OrionDBExplorer.get_annotations
      ~OrionDBExplorer.get_datarun
      ~OrionDBExplorer.get_dataruns
      ~OrionDBExplorer.get_dataset
      ~OrionDBExplorer.get_datasets
      ~OrionDBExplorer.get_event
      ~OrionDBExplorer.get_events
      ~OrionDBExplorer.get_experiment
      ~OrionDBExplorer.get_experiments
      ~OrionDBExplorer.get_pipeline
      ~OrionDBExplorer.get_pipelines
      ~OrionDBExplorer.get_signal
      ~OrionDBExplorer.get_signalrun
      ~OrionDBExplorer.get_signalruns
      ~OrionDBExplorer.get_signals
      ~OrionDBExplorer.get_template
      ~OrionDBExplorer.get_templates
   
   

   
   
   